Switch26P class

Inheritance

Constructors

Switch26P()
const

Properties

evenPortOffsetR List<Offset>
Normalized (x, y) positions for even-numbered ports (2, 4, 6 …).
finalinherited
hashCode int
The hash code for this object.
no setterinherited
hSizeFactor double
Height of the switch body as a fraction of the center device size.
finalinherited
isStacked bool
Whether this is a stacked (two-unit) switch.
finalinherited
minHeight double
Minimum viewport height for this layout.
finalinherited
minWidth double
Minimum viewport width for this layout.
finalinherited
oddPortOffsetR List<Offset>
Normalized (x, y) positions for odd-numbered ports (1, 3, 5 …).
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
totalPortsNum int
Total port slots (48 for stacked configurations).
finalinherited
validPortsNum int?
Actual valid ports (null for single-unit switches).
finalinherited
wSizeFactor double
Width of the switch body as a fraction of the center device size.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited